# Changelog

## [0.4.2](https://github.com/MartinHjelmare/leicacam/tree/0.4.2) (2020-06-10)

[Full Changelog](https://github.com/MartinHjelmare/leicacam/compare/0.4.1...0.4.2)

**Merged pull requests:**

- Delint commands markdown [\#48](https://github.com/MartinHjelmare/leicacam/pull/48) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Remove stale changelog script [\#47](https://github.com/MartinHjelmare/leicacam/pull/47) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix release action [\#46](https://github.com/MartinHjelmare/leicacam/pull/46) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Update changelog [\#45](https://github.com/MartinHjelmare/leicacam/pull/45) ([github-actions[bot]](https://github.com/apps/github-actions))

## [0.4.1](https://github.com/MartinHjelmare/leicacam/tree/0.4.1) (2020-06-10)

[Full Changelog](https://github.com/MartinHjelmare/leicacam/compare/0.4.0...0.4.1)

**Merged pull requests:**

- Update readme build badge [\#44](https://github.com/MartinHjelmare/leicacam/pull/44) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add github action release workflow [\#43](https://github.com/MartinHjelmare/leicacam/pull/43) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add release-drafter [\#42](https://github.com/MartinHjelmare/leicacam/pull/42) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Clean setup.py [\#41](https://github.com/MartinHjelmare/leicacam/pull/41) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add github actions CI test [\#40](https://github.com/MartinHjelmare/leicacam/pull/40) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix linting and spelling [\#39](https://github.com/MartinHjelmare/leicacam/pull/39) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Scheduled monthly dependency update for June [\#38](https://github.com/MartinHjelmare/leicacam/pull/38) ([pyup-bot](https://github.com/pyup-bot))
- Scheduled monthly dependency update for May [\#37](https://github.com/MartinHjelmare/leicacam/pull/37) ([pyup-bot](https://github.com/pyup-bot))
- Scheduled monthly dependency update for April [\#36](https://github.com/MartinHjelmare/leicacam/pull/36) ([pyup-bot](https://github.com/pyup-bot))
- Scheduled monthly dependency update for March [\#35](https://github.com/MartinHjelmare/leicacam/pull/35) ([pyup-bot](https://github.com/pyup-bot))
- Scheduled monthly dependency update for February [\#34](https://github.com/MartinHjelmare/leicacam/pull/34) ([pyup-bot](https://github.com/pyup-bot))
- Add vscode to gitignore [\#33](https://github.com/MartinHjelmare/leicacam/pull/33) ([MartinHjelmare](https://github.com/MartinHjelmare))

## [0.4.0](https://github.com/MartinHjelmare/leicacam/tree/0.4.0) (2019-11-09)

[Full Changelog](https://github.com/MartinHjelmare/leicacam/compare/0.3.0...0.4.0)

**Merged pull requests:**

- Add black code formatter [\#32](https://github.com/MartinHjelmare/leicacam/pull/32) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix release script [\#31](https://github.com/MartinHjelmare/leicacam/pull/31) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix message parsing [\#30](https://github.com/MartinHjelmare/leicacam/pull/30) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add Python 3.8 tox and travis env [\#29](https://github.com/MartinHjelmare/leicacam/pull/29) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Scheduled monthly dependency update for November [\#28](https://github.com/MartinHjelmare/leicacam/pull/28) ([pyup-bot](https://github.com/pyup-bot))
- Fix docs build [\#27](https://github.com/MartinHjelmare/leicacam/pull/27) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add readme docs badge [\#26](https://github.com/MartinHjelmare/leicacam/pull/26) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix readme badges and links [\#25](https://github.com/MartinHjelmare/leicacam/pull/25) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Scheduled monthly dependency update for October [\#24](https://github.com/MartinHjelmare/leicacam/pull/24) ([pyup-bot](https://github.com/pyup-bot))
- Add readthedocs config yml file [\#23](https://github.com/MartinHjelmare/leicacam/pull/23) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Remove mock dependency [\#22](https://github.com/MartinHjelmare/leicacam/pull/22) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Drop support of Python 2.7 [\#21](https://github.com/MartinHjelmare/leicacam/pull/21) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Scheduled monthly dependency update for September [\#20](https://github.com/MartinHjelmare/leicacam/pull/20) ([pyup-bot](https://github.com/pyup-bot))
- Add .pyup.yml [\#19](https://github.com/MartinHjelmare/leicacam/pull/19) ([MartinHjelmare](https://github.com/MartinHjelmare))

## [0.3.0](https://github.com/MartinHjelmare/leicacam/tree/0.3.0) (2018-12-08)

[Full Changelog](https://github.com/MartinHjelmare/leicacam/compare/0.2.2...0.3.0)

**Merged pull requests:**

- Pin and update requirements [\#18](https://github.com/MartinHjelmare/leicacam/pull/18) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Update docs with new module [\#17](https://github.com/MartinHjelmare/leicacam/pull/17) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Use README markdown for pypi description [\#16](https://github.com/MartinHjelmare/leicacam/pull/16) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add asyncio support [\#15](https://github.com/MartinHjelmare/leicacam/pull/15) ([MartinHjelmare](https://github.com/MartinHjelmare))

## [0.2.2](https://github.com/MartinHjelmare/leicacam/tree/0.2.2) (2018-06-21)

[Full Changelog](https://github.com/MartinHjelmare/leicacam/compare/0.2.1...0.2.2)

**Merged pull requests:**

- Remove nullbyte from incomming message [\#14](https://github.com/MartinHjelmare/leicacam/pull/14) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add decorator logger for pydebug [\#13](https://github.com/MartinHjelmare/leicacam/pull/13) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Install everything needed in dev requirements [\#12](https://github.com/MartinHjelmare/leicacam/pull/12) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Update makefile help and phony [\#11](https://github.com/MartinHjelmare/leicacam/pull/11) ([MartinHjelmare](https://github.com/MartinHjelmare))

## [0.2.1](https://github.com/MartinHjelmare/leicacam/tree/0.2.1) (2018-04-05)

[Full Changelog](https://github.com/MartinHjelmare/leicacam/compare/v0.2.0...0.2.1)

**Merged pull requests:**

- Enhance release procedure [\#10](https://github.com/MartinHjelmare/leicacam/pull/10) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Clean up setup.py [\#9](https://github.com/MartinHjelmare/leicacam/pull/9) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add more tests [\#8](https://github.com/MartinHjelmare/leicacam/pull/8) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Format examples in docs [\#7](https://github.com/MartinHjelmare/leicacam/pull/7) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Make docs build cleanly and add links [\#6](https://github.com/MartinHjelmare/leicacam/pull/6) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Fix readme [\#5](https://github.com/MartinHjelmare/leicacam/pull/5) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Add linters to tox and travis [\#4](https://github.com/MartinHjelmare/leicacam/pull/4) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Update tox and travis [\#3](https://github.com/MartinHjelmare/leicacam/pull/3) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Clean requirements [\#2](https://github.com/MartinHjelmare/leicacam/pull/2) ([MartinHjelmare](https://github.com/MartinHjelmare))
- Switch broken pypip.in badges to shields.io [\#1](https://github.com/MartinHjelmare/leicacam/pull/1) ([movermeyer](https://github.com/movermeyer))

## [v0.2.0](https://github.com/MartinHjelmare/leicacam/tree/v0.2.0) (2015-04-23)

[Full Changelog](https://github.com/MartinHjelmare/leicacam/compare/v0.1.1...v0.2.0)

## [v0.1.1](https://github.com/MartinHjelmare/leicacam/tree/v0.1.1) (2015-03-17)

[Full Changelog](https://github.com/MartinHjelmare/leicacam/compare/v0.1.0...v0.1.1)

## [v0.1.0](https://github.com/MartinHjelmare/leicacam/tree/v0.1.0) (2015-03-15)

[Full Changelog](https://github.com/MartinHjelmare/leicacam/compare/v0.0.2...v0.1.0)

## [v0.0.2](https://github.com/MartinHjelmare/leicacam/tree/v0.0.2) (2015-03-15)

[Full Changelog](https://github.com/MartinHjelmare/leicacam/compare/8781477cf0bb4cfd5a32f3eb0fc12b2c4c5f12e2...v0.0.2)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
